# Licensed under Apache License Version 2.0 - see LICENSE

"""Utilities based on Pythons iterators and generators."""

from _iteration_utilities import *

from ._utils import *
from ._recipes import *
from ._additional_recipes import *
from ._classes import *

__version__ = '0.7.0'



# Licensed under Apache License Version 2.0 - see LICENSE

# Built-ins
from __future__ import absolute_import, division, print_function
import sys

__all__ = ['EQ_PY2', 'GE_PY3', 'GE_PY34', 'GE_PY35', '_default']

EQ_PY2 = sys.version_info.major == 2
GE_PY3 = sys.version_info.major >= 3
GE_PY34 = sys.version_info.major > 3 or (sys.version_info.major == 3 and
                                         sys.version_info.minor >= 4)
GE_PY35 = sys.version_info.major > 3 or (sys.version_info.major == 3 and
                                         sys.version_info.minor >= 5)


class _SentinelFactory(object):
    __slots__ = ('_name', )

    def __init__(self, name):
        self._name = name

    # Representation and casting to strings
    def __repr__(self):
        return str(self._name)

    def __str__(self):
        return str(self._name)


_default = _SentinelFactory('<default>')



# Licensed under Apache License Version 2.0 - see LICENSE

# Built-ins
from __future__ import absolute_import, division, print_function
import itertools

# This module
from ._utils import EQ_PY2, GE_PY35


__all__ = ['filter', 'filterfalse', 'map', 'UserString', 'range', 'zip',
           'zip_longest', 'string_types']

filter = itertools.ifilter if EQ_PY2 else filter
filterfalse = itertools.ifilterfalse if EQ_PY2 else itertools.filterfalse
map = itertools.imap if EQ_PY2 else map
range = xrange if EQ_PY2 else range
zip = itertools.izip if EQ_PY2 else zip
zip_longest = itertools.izip_longest if EQ_PY2 else itertools.zip_longest

string_types = basestring if EQ_PY2 else str

RecursionError = RecursionError if GE_PY35 else RuntimeError
AttributeUnwriteableException = TypeError if EQ_PY2 else AttributeError

if EQ_PY2:
    from UserString import UserString
else:
    from collections import UserString
